Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: components/html_viewer/html_document_application_delegate.h

Issue 1675083002: Rename ApplicationDelegate to ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/html_viewer/html_document_application_delegate.h
diff --git a/components/html_viewer/html_document_application_delegate.h b/components/html_viewer/html_document_application_delegate.h
index b28dde5e4b3e5a2ed99ab147cc0093b1d0f78ff0..88700211d8da7d94a8d8f25f744d543d275df19d 100644
--- a/components/html_viewer/html_document_application_delegate.h
+++ b/components/html_viewer/html_document_application_delegate.h
@@ -13,17 +13,17 @@
#include "components/html_viewer/html_factory.h"
#include "mojo/public/cpp/bindings/interface_request.h"
#include "mojo/services/network/public/interfaces/url_loader_factory.mojom.h"
-#include "mojo/shell/public/cpp/application_delegate.h"
#include "mojo/shell/public/cpp/application_impl.h"
#include "mojo/shell/public/cpp/shell.h"
+#include "mojo/shell/public/cpp/shell_client.h"
namespace html_viewer {
class GlobalState;
class HTMLDocument;
-// ApplicationDelegate created by the content handler for a specific url.
-class HTMLDocumentApplicationDelegate : public mojo::ApplicationDelegate,
+// mojo::ShellClient created by the content handler for a specific url.
+class HTMLDocumentApplicationDelegate : public mojo::ShellClient,
public HTMLFactory {
public:
HTMLDocumentApplicationDelegate(
@@ -42,21 +42,20 @@ class HTMLDocumentApplicationDelegate : public mojo::ApplicationDelegate,
~HTMLDocumentApplicationDelegate() override;
// Callback from the quit closure. We key off this rather than
// ApplicationDelegate::Quit() as we don't want to shut down the messageloop
// when we quit (the messageloop is shared among multiple
// HTMLDocumentApplicationDelegates).
void OnTerminate();
- // ApplicationDelegate:
+ // mojo::ShellClient:
void Initialize(mojo::Shell* shell, const std::string& url,
uint32_t id) override;
- bool AcceptConnection(
- mojo::ApplicationConnection* connection) override;
+ bool AcceptConnection(mojo::Connection* connection) override;
void OnHTMLDocumentDeleted2(HTMLDocument* document);
void OnResponseReceived(scoped_ptr<mojo::AppRefCount> app_refcount,
mojo::URLLoaderPtr loader,
- mojo::ApplicationConnection* connection,
+ mojo::Connection* connection,
scoped_ptr<ServiceConnectorQueue> connector_queue,
mojo::URLResponsePtr response);
« no previous file with comments | « components/html_viewer/html_document.cc ('k') | components/html_viewer/html_document_application_delegate.cc » ('j') | no next file with comments »
@@ -42,21 +42,20 @@ class HTMLDocumentApplicationDelegate : public mojo::ApplicationDelegate,
~HTMLDocumentApplicationDelegate() override;
// Callback from the quit closure. We key off this rather than
- // ApplicationDelegate::Quit() as we don't want to shut down the messageloop
+ // ShellClient::Quit() as we don't want to shut down the messageloop
// when we quit (the messageloop is shared among multiple
// HTMLDocumentApplicationDelegates).

Powered by Google App Engine
This is Rietveld 408576698